@@ -1,12 +1,17 @@
+from __future__ import annotations
+
 from collections import defaultdict
 from dataclasses import dataclass, field
 from random import Random
-from typing import TYPE_CHECKING, Any, DefaultDict, Dict, MutableSequence, Optional, Sequence, Tuple, Union, cast
+from typing import TYPE_CHECKING, Dict, Union, cast
 
-from ... import AnyResolution, FreeResponseResolution, MultipleChoiceResolution
+from ...util import normalize_mapping
 from .. import ResolutionValueRule, get_rule
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
+    from typing import Any, DefaultDict, Mapping, MutableSequence, Optional, Sequence, Tuple
+
+    from ... import AnyResolution, FreeResponseResolution, MultipleChoiceResolution
     from ...market import Market
 
 
@@ -16,10 +21,10 @@ class ResolveToValue(ResolutionValueRule):
 
     resolve_value: AnyResolution
 
-    def _value(self, market: 'Market') -> AnyResolution:
+    def _value(self, market: Market) -> AnyResolution:
         return self.resolve_value
 
-    def explain_abstract(self, indent: int = 0, **kwargs: Any) -> str:
+    def _explain_abstract(self, indent: int = 0, **kwargs: Any) -> str:
         return f"{'  ' * indent}- Resolves to the specific value {self.resolve_value}\n"
 
 
@@ -33,7 +38,7 @@ class ResolveRandomSeed(ResolutionValueRule):
     args: Sequence[Any] = ()
     kwargs: Dict[str, Any] = field(default_factory=dict)
 
-    def _value(self, market: 'Market') -> Any:
+    def _value(self, market: Market) -> Any:
         source = Random(self.seed)
         method = getattr(source, self.method)
         for _ in range(self.rounds):
@@ -64,7 +69,7 @@ class ResolveRandomIndex(ResolveRandomSeed):
             method = 'randrange'
         super().__init__(seed, method, *args, **kwargs)
 
-    def _value(self, market: 'Market') -> int:
+    def _value(self, market: Market) -> int:
         if self.method == 'randrange':
             self.args = (self.start, self.size)
         else:
@@ -73,7 +78,7 @@ class ResolveRandomIndex(ResolveRandomSeed):
             self.kwargs["weights"] = [prob for _, prob in items]
         return cast(int, super()._value(market))
 
-    def explain_abstract(self, indent: int = 0, **kwargs: Any) -> str:
+    def _explain_abstract(self, indent: int = 0, **kwargs: Any) -> str:
         ret = f"{'  ' * indent}- Resolve to a random index, given some original seed. This one operates on a "
         if self.method == 'randrange':
             ret += f"fixed range of integers in ({self.start} <= x < {self.size}).\n"
@@ -88,15 +93,15 @@ class ResolveMultipleValues(ResolutionValueRule):
 
     shares: MutableSequence[Tuple[ResolutionValueRule, float]] = field(default_factory=list)
 
-    def _value(self, market: 'Market') -> Union[FreeResponseResolution, MultipleChoiceResolution]:
+    def _value(self, market: Market) -> Union[FreeResponseResolution, MultipleChoiceResolution]:
         ret: DefaultDict[int, float] = defaultdict(float)
         for rule, part in self.shares:
             val = cast(Dict[Union[str, int], float], rule.value(market, format='FREE_RESPONSE'))
             for idx, value in val.items():
                 ret[int(idx)] += value * part
-        return {key: value for key, value in ret.items()}
+        return normalize_mapping(ret)
 
-    def explain_abstract(self, indent: int = 0, **kwargs: Any) -> str:
+    def _explain_abstract(self, indent: int = 0, **kwargs: Any) -> str:
         ret = f"{'  ' * indent}Resolves to the weighted union of multiple other values.\n"
         indent += 1
         for rule, weight in self.shares:
@@ -105,8 +110,9 @@ class ResolveMultipleValues(ResolutionValueRule):
         return ret
 
     @classmethod
-    def from_dict(cls, env: Dict[str, Any]) -> 'ResolveMultipleValues':
+    def from_dict(cls, env: Mapping[str, Any]) -> 'ResolveMultipleValues':
         """Take a dictionary and return an instance of the associated class."""
+        env_copy: Dict[str, Any] = dict(env)
         shares: MutableSequence[Tuple[ResolutionValueRule, float]] = env['shares']
         new_shares = []
         for rule, weight in shares:
@@ -116,5 +122,5 @@ class ResolveMultipleValues(ResolutionValueRule):
                 new_shares.append((new_rule, weight))
             except Exception:
                 pass
-        env['shares'] = new_shares
-        return cast(ResolveMultipleValues, super().from_dict(env))
+        env_copy['shares'] = new_shares
+        return cast(ResolveMultipleValues, super().from_dict(env_copy))
